@@ -24,7 +24,7 @@ class ValidationLogger(object):
         self.num_errors = 0
         self.num_warnings = 0
         self.info = 0
-        self.spec = 'https://ocfl.io/draft/spec/'
+        self.spec = 'https://ocfl.io/1.0/spec/'
         if self.validation_codes is None:
             with open(os.path.join(os.path.dirname(__file__), 'data/validation-errors.json'), 'r') as fh:
                 self.validation_codes = json.load(fh)
